@@ -18,7 +18,7 @@ use Data::Dumper;
 use Data::UUID;
 use WebService::Yahoo::BOSS::Response;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 our $Ua = LWP::UserAgent->new( agent => __PACKAGE__ . '_' . $VERSION );
 
@@ -58,8 +58,8 @@ sub Web {
 
     # Create request
     my $request = Net::OAuth->request("request token")->new(
-        consumer_key     => $args{ckey},
-        consumer_secret  => $args{csecret},
+        consumer_key     => $self->ckey,
+        consumer_secret  => $self->csecret,
         request_url      => $url,
         request_method   => 'GET',
         signature_method => 'HMAC-SHA1',
